@@ -2,7 +2,6 @@
 
 fontpath=/usr/share/inventor/fonts
 type1=/usr/share/fonts/X11/Type1
-urw=/usr/share/fonts/type1/urw-base35
 
 mkdir -p $fontpath
 cd $fontpath
@@ -11,10 +10,10 @@ ln -s -f $type1/c0419bt_.pfb  Courier-Regular
 ln -s -f $type1/c0582bt_.pfb  Courier-Italic
 ln -s -f $type1/c0583bt_.pfb  Courier-Bold
 ln -s -f $type1/c0611bt_.pfb  Courier-BoldItalic
-ln -s -f $urw/C059-Roman.t1  Century-Schoolbook-Roman
-ln -s -f $urw/C059-Bold.t1  Century-Schoolbook-Bold
-ln -s -f $urw/C059-Italic.t1  Century-Schoolbook-Italic
-ln -s -f $urw/C059-BdIta.t1  Century-Schoolbook-BoldItalic
+ln -s -f $type1/c059013l.pfb  Century-Schoolbook-Roman
+ln -s -f $type1/c059016l.pfb  Century-Schoolbook-Bold
+ln -s -f $type1/c059033l.pfb  Century-Schoolbook-Italic
+ln -s -f $type1/c059036l.pfb  Century-Schoolbook-BoldItalic
 
 
 for i in $type1/*.pfa; do
